@@ -1,7 +1,7 @@
 package Bencher::Scenario::SetOperationModules;
 
 our $DATE = '2015-11-13'; # DATE
-our $VERSION = '0.03'; # VERSION
+our $VERSION = '0.04'; # VERSION
 
 use 5.010001;
 use strict;
@@ -120,6 +120,14 @@ our $scenario = {
                 set2 => [2..101],
             },
         },
+        {
+            name => 'num1000',
+            args => {
+                set1 => [1..1000],
+                set2 => [2..1001],
+            },
+            include_by_default => 0,
+        },
     ],
 };
 
@@ -138,7 +146,7 @@ Bencher::Scenario::SetOperationModules - Benchmark Perl set operation (union, in
 
 =head1 VERSION
 
-This document describes version 0.03 of Bencher::Scenario::SetOperationModules (from Perl distribution Bencher-Scenario-SetOperationModules), released on 2015-11-13.
+This document describes version 0.04 of Bencher::Scenario::SetOperationModules (from Perl distribution Bencher-Scenario-SetOperationModules), released on 2015-11-13.
 
 =head1 SYNOPSIS
 
